"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.buildProductionBundle = void 0;

var _webpack = _interopRequireDefault(require("webpack"));

var _flatMap = _interopRequireDefault(require("lodash/flatMap"));

var _webpack2 = _interopRequireDefault(require("../utils/webpack.config"));

var _webpackErrorUtils = require("../utils/webpack-error-utils");

const buildProductionBundle = async (program, parentSpan) => {
  const {
    directory
  } = program;
  const compilerConfig = await (0, _webpack2.default)(program, directory, `build-javascript`, null, {
    parentSpan
  });
  return new Promise((resolve, reject) => {
    (0, _webpack.default)(compilerConfig).run((err, stats) => {
      if (err) {
        return reject(err);
      }

      (0, _webpackErrorUtils.reportWebpackWarnings)(stats);

      if (stats.hasErrors()) {
        const flattenStatsErrors = stats => [...stats.compilation.errors, ...(0, _flatMap.default)(stats.compilation.children, child => flattenStatsErrors(child.getStats()))];

        return reject(flattenStatsErrors(stats));
      }

      return resolve(stats);
    });
  });
};

exports.buildProductionBundle = buildProductionBundle;
//# sourceMappingURL=build-javascript.js.map