"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

const fs = require(`fs`);

const path = require(`path`);

const React = require(`react`);

const {
  useState,
  useContext,
  useEffect
} = require(`react`);

const {
  render,
  Box,
  Text,
  useInput,
  useApp
} = require(`ink`);

const Spinner = require(`ink-spinner`).default;

const unified = require(`unified`);

const remarkMdx = require(`remark-mdx`);

const remarkParse = require(`remark-parse`);

const remarkStringify = require(`remark-stringify`);

const jsxToJson = require(`simplified-jsx-to-json`);

const visit = require(`unist-util-visit`);

const humanizeList = require(`humanize-list`);

const {
  createClient,
  useMutation,
  useSubscription,
  Provider,
  defaultExchanges,
  subscriptionExchange
} = require(`urql`);

const {
  SubscriptionClient
} = require(`subscriptions-transport-ws`);

const fetch = require(`node-fetch`);

const ws = require(`ws`);

module.exports = recipe => {
  let recipePath = path.join(__dirname, recipe);

  if (recipePath.slice(-4) !== `.mdx`) {
    recipePath += `.mdx`;
  }

  const recipeSrc = fs.readFileSync(recipePath, `utf8`);
  const GRAPHQL_ENDPOINT = `http://localhost:4000/graphql`;
  const subscriptionClient = new SubscriptionClient(`ws://localhost:4000/graphql`, {
    reconnect: true
  }, ws);
  const client = createClient({
    fetch,
    url: GRAPHQL_ENDPOINT,
    exchanges: [...defaultExchanges, subscriptionExchange({
      forwardSubscription(operation) {
        return subscriptionClient.request(operation);
      }

    })]
  });

  const Div = props => React.createElement(Box, (0, _extends2.default)({
    width: 80,
    textWrap: "wrap",
    flexDirection: "column"
  }, props));

  const u = unified().use(remarkParse).use(remarkStringify).use(remarkMdx);
  const ast = u.parse(recipeSrc);
  const steps = [];
  let index = 0;
  ast.children.forEach(node => {
    if (node.type === `thematicBreak`) {
      index++;
      return;
    }

    steps[index] = steps[index] || [];
    steps[index].push(node);
  });

  const asRoot = nodes => {
    return {
      type: `root`,
      children: nodes
    };
  };

  const stepsAsMDX = steps.map(nodes => {
    const stepAst = asRoot(nodes);
    return u.stringify(stepAst);
  });

  const toJson = value => {
    const obj = {};
    jsxToJson(value).forEach(([type, props = {}]) => {
      if (type === `\n`) {
        return;
      }

      obj[type] = obj[type] || [];
      obj[type].push(props);
    });
    return obj;
  };

  const allCommands = steps.map(nodes => {
    const stepAst = asRoot(nodes);
    let cmds = [];
    visit(stepAst, `jsx`, node => {
      const jsx = node.value;
      cmds = cmds.concat(toJson(jsx));
    });
    return cmds;
  }).reduce((acc, curr) => {
    const cmdByName = {};
    curr.map(v => {
      Object.entries(v).forEach(([key, value]) => {
        cmdByName[key] = cmdByName[key] || [];
        cmdByName[key] = cmdByName[key].concat(value);
      });
    });
    return [...acc, cmdByName];
  }, []);

  const RecipeInterpreter = ({
    commands
  }) => {
    const [lastKeyPress, setLastKeyPress] = useState(``);
    const {
      exit
    } = useApp();
    const [subscriptionResponse] = useSubscription({
      query: `
        subscription {
          operation {
            state
            data
          }
        }
      `
    }, (_prev, now) => now);
    const [_, createOperation] = useMutation(`
    mutation ($commands: String!) {
      createOperation(commands: $commands)
    }
  `);

    subscriptionClient.connectionCallback = () => {
      createOperation({
        commands: JSON.stringify(commands)
      });
    };

    const {
      data
    } = subscriptionResponse;
    const operation = data && data.operation && data.operation.data && JSON.parse(data.operation.data) || commands;
    const state = data && data.operation && data.operation.state;
    useInput((_, key) => {
      setLastKeyPress(key);

      if (key.return && state === `SUCCESS`) {
        subscriptionClient.close();
        exit(); // TODO figure out why exiting ink isn't enough.

        process.exit();
      }
    });
    return React.createElement(React.Fragment, null, React.createElement(Div, null, process.env.DEBUG ? React.createElement(Text, null, JSON.stringify(subscriptionResponse, null, 2)) : null), React.createElement(Div, null, process.env.DEBUG ? React.createElement(Text, null, "Last Key Press: ", JSON.stringify(lastKeyPress, null, 2)) : null), React.createElement(Div, null, process.env.DEBUG ? React.createElement(Text, null, "STATE: ", state) : null), operation.map((command, i) => React.createElement(Div, {
      key: i
    }, React.createElement(Step, {
      command: command
    }), React.createElement(Div, null))), state === `SUCCESS` ? React.createElement(Div, null, React.createElement(Text, null, " "), React.createElement(Text, null, "Your recipe is served! Press enter to exit.")) : null);
  };

  const StateIndicator = ({
    state
  }) => {
    if (state === `complete`) {
      return React.createElement(Text, null, " \u2705 ");
    } else if (state === `error`) {
      return React.createElement(Text, null, " \u274C ");
    } else {
      return React.createElement(Spinner, null);
    }
  };

  const Config = ({
    commands
  }) => {
    const cmd = commands[0]; // Config should only be called once.

    const verb = cmd.state !== `complete` ? `Setting` : `Set`;
    return React.createElement(Div, null, React.createElement(Box, null, React.createElement(StateIndicator, {
      state: cmd.state
    }), React.createElement(Text, null, " "), React.createElement(Text, null, verb, " up plan for ", cmd.name)));
  };

  const NPMPackage = ({
    commands
  }) => {
    const incomplete = commands.some(c => c.state !== `complete`);
    const names = commands.map(c => c.name);

    if (incomplete) {
      return React.createElement(Div, null, React.createElement(Text, null, "Installing packages"), commands.map(cmd => React.createElement(Div, {
        key: cmd.name
      }, React.createElement(Box, null, React.createElement(Text, null, " "), React.createElement(StateIndicator, {
        state: cmd.state
      }), React.createElement(Text, null, " "), React.createElement(Text, null, cmd.name)))));
    }

    return React.createElement(Div, null, React.createElement(Box, null, React.createElement(StateIndicator, {
      state: "complete"
    }), React.createElement(Text, null, " "), React.createElement(Text, null, "Installed ", humanizeList(names))));
  };

  const NPMScript = ({
    commands
  }) => {
    const incomplete = commands.some(c => c.state !== `complete`);
    const names = commands.map(c => c.name);

    if (incomplete) {
      return React.createElement(Div, null, React.createElement(Text, null, "Adding scripts"), commands.map(cmd => React.createElement(Div, {
        key: cmd.name
      }, React.createElement(Box, null, React.createElement(Text, null, " "), React.createElement(StateIndicator, {
        state: cmd.state
      }), React.createElement(Text, null, " "), React.createElement(Text, null, cmd.name)))));
    }

    return React.createElement(Div, null, React.createElement(Box, null, React.createElement(StateIndicator, {
      state: "complete"
    }), React.createElement(Text, null, " "), React.createElement(Text, null, "Added scripts for ", humanizeList(names))));
  };

  const GatsbyPlugin = ({
    commands
  }) => {
    const incomplete = commands.some(c => c.state !== `complete`);
    const names = commands.map(c => c.name);

    if (incomplete) {
      return React.createElement(Div, null, React.createElement(Text, null, "Configuring plugins"), commands.map(cmd => React.createElement(Div, {
        key: cmd.name
      }, React.createElement(Box, null, React.createElement(Text, null, " "), React.createElement(StateIndicator, {
        state: cmd.state
      }), React.createElement(Text, null, " "), React.createElement(Text, null, cmd.name)))));
    }

    return React.createElement(Div, null, React.createElement(Box, null, React.createElement(StateIndicator, {
      state: "complete"
    }), React.createElement(Text, null, " "), React.createElement(Text, null, "Configured ", humanizeList(names))));
  };

  const ShadowFile = ({
    commands
  }) => {
    const incomplete = commands.some(c => c.state !== `complete`);
    const paths = commands.map(c => c.path);

    if (incomplete) {
      return React.createElement(Div, null, React.createElement(Text, null, "Shadowing files"), commands.map(cmd => React.createElement(Div, {
        key: cmd.path
      }, React.createElement(Box, null, React.createElement(Text, null, " "), React.createElement(StateIndicator, {
        state: cmd.state
      }), React.createElement(Text, null, " "), React.createElement(Text, null, cmd.path)))));
    }

    return React.createElement(Div, null, React.createElement(Box, null, React.createElement(StateIndicator, {
      state: "complete"
    }), React.createElement(Text, null, " "), React.createElement(Text, null, "Shadowed ", humanizeList(paths))));
  };

  const File = ({
    commands
  }) => {
    const incomplete = commands.some(c => c.state !== `complete`);
    const paths = commands.map(c => c.path);

    if (incomplete) {
      return React.createElement(Div, null, React.createElement(Text, null, "Writing files"), commands.map(cmd => React.createElement(Div, {
        key: cmd.path
      }, React.createElement(Box, null, React.createElement(Text, null, " "), React.createElement(StateIndicator, {
        state: cmd.state
      }), React.createElement(Text, null, " "), React.createElement(Text, null, cmd.path)))));
    }

    return React.createElement(Div, null, React.createElement(Box, null, React.createElement(StateIndicator, {
      state: "complete"
    }), React.createElement(Text, null, " "), React.createElement(Text, null, "Created file ", humanizeList(paths))));
  };

  const Step = ({
    command
  }) => Object.entries(command).map(([cmdName, cmds], i) => {
    if (cmdName === `Config`) {
      return React.createElement(Config, {
        key: i,
        commands: cmds
      });
    } else if (cmdName === `NPMPackage`) {
      return React.createElement(NPMPackage, {
        key: i,
        commands: cmds
      });
    } else if (cmdName === `NPMScript`) {
      return React.createElement(NPMScript, {
        key: i,
        commands: cmds
      });
    } else if (cmdName === `GatsbyPlugin`) {
      return React.createElement(GatsbyPlugin, {
        key: i,
        commands: cmds
      });
    } else if (cmdName === `ShadowFile`) {
      return React.createElement(ShadowFile, {
        key: i,
        commands: cmds
      });
    } else if (cmdName === `File`) {
      return React.createElement(File, {
        key: i,
        commands: cmds
      });
    } else {
      return React.createElement(Text, {
        key: i
      }, cmdName);
    }
  });

  const Wrapper = () => React.createElement(Provider, {
    value: client
  }, React.createElement(RecipeInterpreter, {
    commands: allCommands
  }));

  const Recipe = () => React.createElement(Wrapper, {
    steps: stepsAsMDX
  });

  render(React.createElement(Recipe, null));
};
//# sourceMappingURL=cli.js.map